% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/models.R
\name{lasso_ista_back}
\alias{lasso_ista_back}
\title{Lasso regression with backtraking line research}
\usage{
lasso_ista_back(data,y,x,lambda,max_step=10000,tol=10^-7,
type="Gaussian",ini=0.5,image=TRUE)
}
\arguments{
\item{data}{name of the dataset}

\item{y}{name of the dependent variables}

\item{x}{name of the independent variable}

\item{lambda}{a vector of lambda-value to be evaluated in the regression}

\item{max_step}{maximum number of steps}

\item{tol}{tolerance for convergence, it is 10^-7 by default}

\item{type}{type of response variable, by default, it is 'Gaussian' for continuos response and can be modified as 'Binomial' for binary response}

\item{ini}{initial value for the coefficients,dafault is 0.5}

\item{image}{plots the evolution of errors in term of lambda values}
}
\value{
A list containing:
\itemize{
  \item{\code{coefficients}: A matrix where each column represents the estimated regression coefficients for a different lambda value.}
  \item{\code{error_evolution}: A numeric vector tracking the error at certain step.}
  \item{\code{num_steps}: An integer vector indicating the number of steps in which errors are calculated.}
}
}
\description{
the function carries out the Lasso regression using backtraking line research and ISTA algorithm.
}
\details{
lasso_ista_back
}
\examples{
library("glmnet")
data("QuickStartExample")
test<-as.data.frame(cbind(QuickStartExample$y,QuickStartExample$x))
lasso_ista_back(test,"V1",colnames(test)[2:21],lambda=0.1,image=TRUE,type='Gaussian',max_step=100)
}
